"""
Constant column type metadata.
"""

_ARRAY = "_ARRAY"
HEADING = "HEADING"
LOGO = "LOGO"
STRING = "STRING"
TEXT = "TEXT"
INT = "INT"
DECIMAL = "DECIMAL"
LONG = "LONG"
BOOL = "BOOL"
HYPERLINK = "HYPERLINK"
DATE = "DATE"
DATETIME = "DATETIME"
REF = "REF"
REFBACK = "REFBACK"
ONTOLOGY = "ONTOLOGY"
SECTION = "SECTION"

STRING_ARRAY = STRING + _ARRAY
TEXT_ARRAY = TEXT + _ARRAY
INT_ARRAY = INT + _ARRAY
DECIMAL_ARRAY = DECIMAL + _ARRAY
LONG = LONG + _ARRAY
BOOL_ARRAY = BOOL + _ARRAY
HYPERLINK_ARRAY = HYPERLINK + _ARRAY
DATE_ARRAY = DATE + _ARRAY
DATETIME_ARRAY = DATETIME + _ARRAY
REF_ARRAY = REF + _ARRAY
ONTOLOGY_ARRAY = ONTOLOGY + _ARRAY
